.. wepy documentation master file, created by
   sphinx-quickstart on Mon Dec 10 13:22:52 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Wepy: A Weighted Ensemble  (WE) simulation framework
====================================================

.. toctree::
   :maxdepth: 1

   source/introduction
   source/installation
   source/explanation
   source/glossary
   source/api
   api/modules
   tutorials/index
   source/architecture


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
